#[non_exhaustive]pub enum WarmupMode {
None,
QueryPlanning,
}Expand description
Selects how much work table loading performs before returning.
Each warmup level includes the work performed by the levels before it. The default performs no warmup and leaves reusable metadata work to individual queries.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
Performs no warmup.
QueryPlanning
Loads and retains the active-file metadata used during query planning.