pub struct DeltaProtocol { /* private fields */ }Expand description
Protocol metadata captured from one immutable Delta snapshot.
Implementations
Sourceimpl DeltaProtocol
impl DeltaProtocol
Sourcepub const fn min_reader_version(&self) -> i32
pub const fn min_reader_version(&self) -> i32
Returns the minimum Delta reader protocol version.
Sourcepub const fn min_writer_version(&self) -> i32
pub const fn min_writer_version(&self) -> i32
Returns the minimum Delta writer protocol version.
Sourcepub fn reader_features(&self) -> &[String]
pub fn reader_features(&self) -> &[String]
Returns the required reader feature names in deterministic Kernel order.
Sourcepub fn writer_features(&self) -> &[String]
pub fn writer_features(&self) -> &[String]
Returns the writer feature names in deterministic Kernel order.
Sourcepub fn first_unsupported_reader_feature(&self) -> Option<&str>
pub fn first_unsupported_reader_feature(&self) -> Option<&str>
Returns the first required reader feature unsupported by this crate.