pub struct DeltaScan { /* private fields */ }Expand description
One immutable, single-use streaming Delta scan plan.
A scan cannot be cloned or converted into a stream twice.
ⓘ
use delta_arrow_reader::DeltaScan;
fn stream_twice(scan: DeltaScan) {
let _ = scan.into_stream();
let _ = scan.into_stream();
}ⓘ
use delta_arrow_reader::DeltaScan;
fn clone_scan(scan: DeltaScan) {
let _ = scan.clone();
}Implementations
Sourceimpl DeltaScan
impl DeltaScan
Sourcepub fn schema(&self) -> SchemaRef
pub fn schema(&self) -> SchemaRef
Returns a shared handle to the visible logical output schema.
Sourcepub fn partition_count(&self) -> usize
pub fn partition_count(&self) -> usize
Returns the number of planned execution partitions.
Sourcepub fn into_stream(self) -> DeltaBatchStream
pub fn into_stream(self) -> DeltaBatchStream
Converts the scan into a pull-driven Arrow batch stream.
Data-file reads begin only when the stream is polled.