pub struct DeltaScanExecutionOptions { /* private fields */ }Expand description
Bounded execution settings for one Delta scan.
Implementations
Sourceimpl DeltaScanExecutionOptions
impl DeltaScanExecutionOptions
Sourcepub const fn parquet_backend(&self) -> ParquetReaderBackend
pub const fn parquet_backend(&self) -> ParquetReaderBackend
Returns the selected Parquet reader backend.
Sourcepub const fn max_concurrent_file_reads_per_scan(&self) -> Option<usize>
pub const fn max_concurrent_file_reads_per_scan(&self) -> Option<usize>
Returns the optional scan-wide file-read limit.
Sourcepub const fn max_concurrent_file_reads_per_partition(&self) -> usize
pub const fn max_concurrent_file_reads_per_partition(&self) -> usize
Returns the per-partition file-read limit.
Sourcepub const fn output_buffer_batches_per_partition(&self) -> usize
pub const fn output_buffer_batches_per_partition(&self) -> usize
Returns the number of output batches buffered per partition.
Sourcepub const fn prefetch_files_per_partition(&self) -> usize
pub const fn prefetch_files_per_partition(&self) -> usize
Returns the number of future direct Parquet files prepared per partition.
Sourcepub const fn parquet_metadata_size_hint_bytes(&self) -> Option<usize>
pub const fn parquet_metadata_size_hint_bytes(&self) -> Option<usize>
Returns the direct Parquet reader’s metadata size hint in bytes.
Sourcepub const fn parquet_full_file_read_threshold_bytes(&self) -> Option<usize>
pub const fn parquet_full_file_read_threshold_bytes(&self) -> Option<usize>
Returns the direct Parquet reader’s full-file read threshold in bytes.
Sourcepub const fn with_parquet_backend(
self,
parquet_backend: ParquetReaderBackend,
) -> Self
pub const fn with_parquet_backend( self, parquet_backend: ParquetReaderBackend, ) -> Self
Selects a Parquet reader backend.
Sourcepub fn with_max_concurrent_file_reads_per_scan(
self,
max_concurrent_file_reads: Option<usize>,
) -> Result<Self, DeltaReaderError>
pub fn with_max_concurrent_file_reads_per_scan( self, max_concurrent_file_reads: Option<usize>, ) -> Result<Self, DeltaReaderError>
Sets or clears the scan-wide file-read limit.
Sourcepub fn with_max_concurrent_file_reads_per_partition(
self,
max_concurrent_file_reads: usize,
) -> Result<Self, DeltaReaderError>
pub fn with_max_concurrent_file_reads_per_partition( self, max_concurrent_file_reads: usize, ) -> Result<Self, DeltaReaderError>
Sets the per-partition file-read limit.
Sourcepub fn with_output_buffer_batches_per_partition(
self,
output_buffer_batches: usize,
) -> Result<Self, DeltaReaderError>
pub fn with_output_buffer_batches_per_partition( self, output_buffer_batches: usize, ) -> Result<Self, DeltaReaderError>
Sets the number of output batches buffered per partition.
Sourcepub const fn with_prefetch_files_per_partition(
self,
prefetch_files: usize,
) -> Self
pub const fn with_prefetch_files_per_partition( self, prefetch_files: usize, ) -> Self
Sets the number of future direct Parquet files prepared per partition.
Sourcepub fn with_parquet_metadata_size_hint_bytes(
self,
metadata_size_hint_bytes: Option<usize>,
) -> Result<Self, DeltaReaderError>
pub fn with_parquet_metadata_size_hint_bytes( self, metadata_size_hint_bytes: Option<usize>, ) -> Result<Self, DeltaReaderError>
Sets or clears the direct Parquet reader’s metadata size hint in bytes.
Sourcepub fn with_parquet_full_file_read_threshold_bytes(
self,
full_file_read_threshold_bytes: Option<usize>,
) -> Result<Self, DeltaReaderError>
pub fn with_parquet_full_file_read_threshold_bytes( self, full_file_read_threshold_bytes: Option<usize>, ) -> Result<Self, DeltaReaderError>
Sets or clears the direct Parquet reader’s full-file read threshold in bytes.