pub struct DeltaDataFusionMetricsSnapshot {
pub reader: DeltaReadMetricsSnapshot,
pub output_batch_size: Option<u64>,
pub dynamic_partition_files_pruned: u64,
pub dynamic_partition_files_kept: u64,
pub dynamic_filters_received: u64,
pub dynamic_filters_accepted: u64,
pub dynamic_filters_unsupported: u64,
pub dynamic_filter_snapshots: u64,
pub dynamic_files_not_pruned_missing_metadata: u64,
pub dynamic_files_not_pruned_unsupported_expression: u64,
}Expand description
Immutable point-in-time DataFusion scan metrics.
Fields
reader: DeltaReadMetricsSnapshotCore reader planning and execution metrics.
output_batch_size: Option<u64>Effective DataFusion task batch size observed at execution.
dynamic_partition_files_pruned: u64Files pruned before admission by a dynamic partition filter.
dynamic_partition_files_kept: u64Files kept after consulting retained dynamic partition filters.
dynamic_filters_received: u64Physical filters offered to the post-optimization hook.
dynamic_filters_accepted: u64Offered filters retained for dynamic partition pruning.
dynamic_filters_unsupported: u64Offered filters rejected by the dynamic partition policy.
dynamic_filter_snapshots: u64Current dynamic expressions consulted during file admission.
dynamic_files_not_pruned_missing_metadata: u64Kept files with missing, invalid, or unparsable partition metadata.
dynamic_files_not_pruned_unsupported_expression: u64Kept files with unavailable, unsupported, or failed expressions.