pub struct DeltaTableBuilder { /* private fields */ }Expand description
Configures and loads one immutable Delta table snapshot.
The asynchronous path uses the caller’s Tokio runtime. Scans return a pull-driven stream and do not materialize the whole table.
Example
use delta_arrow_reader::{DeltaComparison, DeltaPredicate, DeltaScalar, DeltaTableBuilder};
use futures_util::TryStreamExt;
let table = DeltaTableBuilder::new("/tmp/example-delta-table")
.load_async()
.await?;
let scan = table
.scan()
.with_projection(vec!["id".into(), "name".into()])
.with_predicate(DeltaPredicate::Compare {
column: "id".into(),
op: DeltaComparison::GtEq,
value: DeltaScalar::Int64(10),
})
.with_limit(100)
.build()
.await?;
let mut batches = scan.execute().await?;
while let Some(batch) = batches.try_next().await? {
println!("rows={}", batch.num_rows());
}Implementations
Sourceimpl DeltaTableBuilder
impl DeltaTableBuilder
Sourcepub fn new(table_uri: impl Into<String>) -> Self
pub fn new(table_uri: impl Into<String>) -> Self
Creates a builder for the latest snapshot with default execution settings.
Sourcepub fn with_storage_options(self, value: DeltaStorageOptions) -> Self
pub fn with_storage_options(self, value: DeltaStorageOptions) -> Self
Replaces the storage options forwarded during table loading.
Sourcepub const fn with_snapshot_selection(
self,
value: DeltaSnapshotSelection,
) -> Self
pub const fn with_snapshot_selection( self, value: DeltaSnapshotSelection, ) -> Self
Selects the Delta snapshot to load.
Sourcepub const fn with_execution_options(
self,
value: DeltaReaderExecutionOptions,
) -> Self
pub const fn with_execution_options( self, value: DeltaReaderExecutionOptions, ) -> Self
Replaces the default execution settings used by scans of this table.
Sourcepub fn load(self) -> Result<DeltaTable, DeltaReaderError>
pub fn load(self) -> Result<DeltaTable, DeltaReaderError>
Loads the snapshot on the calling thread.
Sourcepub async fn load_async(self) -> Result<DeltaTable, DeltaReaderError>
pub async fn load_async(self) -> Result<DeltaTable, DeltaReaderError>
Loads the snapshot through the caller-owned Tokio runtime.
Sourcepub fn load_snapshot(self) -> Result<DeltaTableSnapshot, DeltaReaderError>
pub fn load_snapshot(self) -> Result<DeltaTableSnapshot, DeltaReaderError>
Loads snapshot metadata without converting its logical Arrow schema.
Sourcepub async fn load_snapshot_async(
self,
) -> Result<DeltaTableSnapshot, DeltaReaderError>
pub async fn load_snapshot_async( self, ) -> Result<DeltaTableSnapshot, DeltaReaderError>
Loads snapshot metadata through the caller-owned Tokio runtime.